/* ****************************************************************
 * Paulo Pedreiras, Jul/2012
 * FreeRTOS PC Port
 *
 * Basic example 2: creates two periodic tasks that run forever
 *                  Task period defined by vTaskDelay
 *
 ****************************************************************** */

#include <stdlib.h>
#include <stdio.h>
#include <conio.h>
#include "FreeRTOS.h"
#include "task.h"
#include "list.h"
#include "queue.h"

/*
 * Local defines
 */
#define TASK_1_MS 1000 // Task Execution Time
#define TASK_1_PRIO configMAX_PRIORITIES-1 // Task Prioriy (higher numbers -> higher priority)
#define TASK_2_MS 250
#define TASK_2_PRIO configMAX_PRIORITIES-2

/*
 * Auxiliary functions
 */
void vPrintMessage( const char * const pcMessageToPrint )
{ /* Prints a message in stdout. Protected against preemption (printf is not reentrant) */
        vTaskSuspendAll();
        {
                printf( "%s", pcMessageToPrint );
                fflush( stdout );
        }
        xTaskResumeAll();
}

/*
 * Task implementation
 */
 
/* Simple task: prints a message in stdout in each iteration */
void Task_1(void *pvParameters)
{
    const char *pcTaskName = "Task 1 is running ....\n";

    for(;;) {
        vPrintMessage(pcTaskName);
        vTaskDelay(TASK_1_MS / portTICK_RATE_MS);
    }
    vTaskDelete(NULL);
}

/* Simple task: prints a message in stdout in each iteration */
void Task_2(void *pvParameters)
{
    const char *pcTaskName = "Task 2 is running ....\n";
    for(;;) {
        vPrintMessage(pcTaskName);
        vTaskDelay(TASK_2_MS / portTICK_RATE_MS);

    }
    vTaskDelete(NULL);
}

/*
 * main function
 */
int main( void )
{
                
        /* Create Tasks T1 and T2*/
        xTaskCreate(Task_1,(const signed char *)"Task 1", configMINIMAL_STACK_SIZE, NULL, TASK_1_PRIO, NULL);
        xTaskCreate(Task_2,(const signed char *)"Task 2", configMINIMAL_STACK_SIZE, NULL, TASK_2_PRIO, NULL);
        
        /* Set the scheduler running.  This function will not return unless a task calls vTaskEndScheduler(). */
        vTaskStartScheduler();

        return 1;
}
/*-----------------------------------------------------------*/


